---
layout: page
title: About
permalink: /about/
---

sltoo is a free and open source requirements management tool.
It is a fork of [rmtoo](https://github.com/florath/rmtoo).

sltoo uses a different approach than most other requirements
management tools: it comes as a command line tool which is optimized
for handling requirements. The power of sltoo lies in the fact that
the development environment can handle the input and output files -
there is no need for a special tool set environment.

Example: if you need to handle baselines (and there often is), sltoo
can be configured using a revision control system, e.g., git. The
revision control system can handle different revisions, baselining,
tagging, branching and many other things extremely well - there is no
reason to reinvent the wheel and making it less efficient.

Let one thing do one thing.

See the [release notes](../release_notes/) for the release history.
